==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/operation_workflow_transition_data.dart <==
part of keyclic_sdk_api.api;

class OperationWorkflowTransitionData {
  OperationWorkflowTransitionData({
    this.transition,
  });

  OperationWorkflowTransitionData.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    transition = json['transition'];
  }

  String transition;
  //enum transitionEnum {  reset,  assign,  accept,  refuse,  progress,  resolve,  };

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is OperationWorkflowTransitionData &&
        runtimeType == other.runtimeType &&
        transition == other.transition;
  }

  @override
  int get hashCode => 0 ^ transition.hashCode;

  Map<String, dynamic> toJson() {
    return {
      'transition': transition,
    };
  }

  @override
  String toString() {
    return 'OperationWorkflowTransitionData[transition=$transition, ]';
  }

  static List<OperationWorkflowTransitionData> listFromJson(
      List<dynamic> json) {
    return json == null
        ? List<OperationWorkflowTransitionData>()
        : json
            .map((value) => OperationWorkflowTransitionData.fromJson(value))
            .toList();
  }

  static Map<String, OperationWorkflowTransitionData> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationWorkflowTransitionData>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationWorkflowTransitionData.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/operation_workflow_transition_data.dart <==
part of keyclic_sdk_api.api;

class OperationWorkflowTransitionData {
  OperationWorkflowTransitionData({
    this.transition,
  });

  OperationWorkflowTransitionData.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    transition = json['transition'];
  }

  /// enum transitionEnum {  assign,  progress,  resolve,  };
  String transition;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OperationWorkflowTransitionData &&
        runtimeType == other.runtimeType &&
        transition == other.transition;
  }

  /// By default hashCode return reference
  @override
  int get hashCode => 0 ^ transition.hashCode;

  static List<OperationWorkflowTransitionData> listFromJson(
      List<dynamic> json) {
    return json == null
        ? <OperationWorkflowTransitionData>[]
        : json
            .map((value) => OperationWorkflowTransitionData.fromJson(value))
            .toList();
  }

  static Map<String, OperationWorkflowTransitionData> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationWorkflowTransitionData>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationWorkflowTransitionData.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'transition': transition,
    };
  }

  @override
  String toString() {
    return 'OperationWorkflowTransitionData[transition=$transition, ]';
  }
}
